@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2010, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2013, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include "AlpsMessage.h"
@@ -61,7 +61,6 @@ static Alps_message us_english[] =
     {ALPS_MSG_HOW, 100, 3, "Process[%d] %s count %d in %s"},
     {ALPS_NODE_COUNT, 104, 3, "Worker[%d] processed %d nodes, %d nodes are left"},
     {ALPS_NODE_MEM_SIZE, 106, 1, "The memory size of a node is about %d bytes"},
-    {ALPS_P_VERSION, 110, 1, "ALPS version 1.1 (Parallel, MPI)"},
     {ALPS_PARAMFILE, 120, 1, "Parameter file: %s"},
     {ALPS_PEAK_MEMORY, 125, 1, "Peak memory usage: %.2f M"},
     {ALPS_RAMPUP_HUB, 130, 1, "Hub[%d]'s rampup took %g seconds to process %d nodes. Node pool has %d nodes"},
@@ -96,22 +95,28 @@ static Alps_message us_english[] =
     {ALPS_T_INFEASIBLE,202, 1, "Problem is infeasible. %d nodes processed, %d nodes left"},
     {ALPS_T_NODE_LIMIT,204, 1, "Reached node limit. %d nodes processed, %d nodes left"},
     {ALPS_T_NO_MEMORY,206, 1, "Out of memory. %d nodes processed, %d nodes left"},
-    {ALPS_T_OPTIMAL,208, 1, "Found an optimal solution. %d nodes processed, %d nodes left"},
+    {ALPS_T_COMPLETE,208, 1, "Search completed."},
     {ALPS_T_SOL_LIMIT,210, 1, "Reached solution limit. %d nodes processed, %d nodes left"},
     {ALPS_T_TIME_LIMIT,230, 1, "Reached time limit. %d nodes processed, %d nodes left"},
-    {ALPS_S_NODE_COUNT, 240, 1, "Processed %d nodes, has %d nodes, best relaxed %g, best feasible %g"},
+    {ALPS_S_NODE_COUNT, 240, 1, "Proc: %d, Part: %d, Cand: %d, Best N: %g, Best S: %g"},
     {ALPS_S_SEARCH_START, 250, 1, "Starting search ..."},
     {ALPS_S_SEARCH_SOL, 255, 3, "Process %d found a better solution %g"},
-    {ALPS_S_FINAL_SOL, 260, 1, "Quality of the best solution found: %g ; depth %d"},
+    {ALPS_S_FINAL_SOL, 260, 1, "Best solution found had quality %g"},
+    {ALPS_S_FINAL_SOL_WD, 261, 1, "Best solution found had quality %g and was found at depth %d"},
     {ALPS_S_FINAL_NO_SOL, 264, 1, "No solution found"},
-    {ALPS_S_FINAL_NODE_PROCESSED, 267, 1, "Number of nodes processed: %d"},
-    {ALPS_S_FINAL_NODE_BRANCHED, 268, 1, "Number of nodes branched: %d"},
-    {ALPS_S_FINAL_NODE_DISCARDED, 269, 1, "Number of nodes pruned before processing: %d"},
-    {ALPS_S_FINAL_NODE_LEFT, 270, 1, "Number of nodes left: %d"},
+    {ALPS_S_FINAL_NODE_PROCESSED, 265, 1, 
+     "Number of nodes fully processed:          %d"},
+    {ALPS_S_FINAL_NODE_PARTIAL, 266, 1, 
+     "Number of nodes partially processed:      %d"},
+    {ALPS_S_FINAL_NODE_BRANCHED, 267, 1, 
+     "Number of nodes branched:                 %d"},
+    {ALPS_S_FINAL_NODE_DISCARDED, 268, 1, 
+     "Number of nodes pruned before processing: %d"},
+    {ALPS_S_FINAL_NODE_LEFT, 270, 1, 
+     "Number of nodes left:                     %d"},
     {ALPS_S_FINAL_DEPTH, 272, 1, "Tree depth: %d"},
     {ALPS_S_FINAL_CPU, 274, 1, "Search CPU time: %.2f seconds"},
     {ALPS_S_FINAL_WALLCLOCK, 278, 1, "Search wall-clock time: %.2f seconds"},
-    {ALPS_S_VERSION, 300, 1, "ALPS version 1.1 (Serial)"},
     {ALPS_DUMMY_END, 999999, 0, ""}
 };
 
